@@ -29,14 +29,16 @@ ssd_plot_data <- function(data, left = "Conc", right = left, ...,
                           label = NULL, shape = NULL, color = NULL, size = 2.5,
                           xlab = "Concentration", ylab = "Species Affected",
                           shift_x = 3, add_x = 0,
-                          big.mark = ",", suffix = "%",
+                          big.mark = ",", 
+                          decimal.mark = getOption("OutDec", "."),
+                          suffix = "%",
                           bounds = c(left = 1, right = 1),
                           trans = "log10", xbreaks = waiver()) {
   .chk_data(data, left, right, weight = NULL, missing = TRUE)
   chk_unused(...)
   chk_null_or(label, vld = vld_string)
   chk_null_or(shape, vld = vld_string)
-  check_names(data, c(unique(c(left, right)), label, shape))
+  check_names(data, unique(c(left, right, label, shape)))
 
   chk_number(shift_x)
   chk_range(shift_x, c(1, 1000))
@@ -44,6 +46,8 @@ ssd_plot_data <- function(data, left = "Conc", right = left, ...,
   chk_number(add_x)
   chk_range(add_x, c(-1000, 1000))
   chk_string(big.mark)
+  chk_string(decimal.mark)
+
 
   .chk_bounds(bounds)
 
@@ -91,7 +95,7 @@ ssd_plot_data <- function(data, left = "Conc", right = left, ...,
   }
 
   gp <- gp + plot_coord_scale(data,
-    xlab = xlab, ylab = ylab, big.mark = big.mark, suffix = suffix,
+    xlab = xlab, ylab = ylab, big.mark = big.mark, decimal.mark = decimal.mark, suffix = suffix,
     trans = trans, xbreaks = xbreaks
   )
 
