@@ -93,8 +93,10 @@ Type ll_llogis_llogis(objective_function<Type>* obj) // normal with parameters m
         pleft = 0;
         if(left(i)>0){ pleft=pmix   * 1/(1+exp(-(log(left(i))-locationlog1)/scalelog1))+
                             (1-pmix)* 1/(1+exp(-(log(left(i))-locationlog2)/scalelog2));};
-        pright=pmix    * 1/(1+exp(-(log(right(i))-locationlog1)/scalelog1))+
-                                       (1-pmix)* 1/(1+exp(-(log(right(i))-locationlog2)/scalelog2));
+        pright = 1;
+        using std::isfinite;
+        if(isfinite(right(i))){ pright=pmix    * 1/(1+exp(-(log(right(i))-locationlog1)/scalelog1))+
+          (1-pmix)* 1/(1+exp(-(log(right(i))-locationlog2)/scalelog2));};
         nll -= weight(i)*log(pright-pleft);
      };
      // mynll(i) = nll;  // for debugging
