@@ -81,7 +81,9 @@ Type ll_lnorm(objective_function<Type>* obj) {
      if(left(i) < right(i)){   // censored data
         pleft = 0;
         if(left(i)>0){ pleft=pnorm(log(left(i)), meanlog, sdlog);};
-        pright = pnorm(log(right(i)), meanlog, sdlog);
+        pright = 1;
+        using std::isfinite;
+        if(isfinite(right(i))){ pright=pnorm(log(right(i)), meanlog, sdlog);};
         nll -= weight(i)*log(pright-pleft);  // contribution to log-likelihood for censored values
      };
      
